import chardet, mimetypes

from pathlib import Path
from urllib.parse import urlparse


class DotDict(dict):
	__getattr__ = dict.__getitem__
	__setattr__ = dict.__setitem__
	__delattr__ = dict.__getitem__


	def copy(self):
		return DotDict(self)

class MhtmlObject(DotDict):
	def __init__(self, idx, part):
		super().__init__()

		self.body = part.get_payload(decode=True)
		self.mimetype = part.get_content_type()
		self.base_type = part.get_content_maintype()
		self.location = part.get_all('Content-Location')[0]
		self.domain = urlparse(self.location).netloc
		self.path = Path(urlparse(self.location).path)
		self.filename = part.get_filename()
		self.encoding = None

		if not self.filename:
			self.filename = self.path.name

		if self.base_type == 'text':
			self.encoding = chardet.detect(self.body)['encoding']
			self.body = self.body.decode(self.encoding or 'ascii')


	def __str__(self):
		return f'{self.__class__.__name__}(name="{self.filename}", location="{self.location}", mimetype="{self.mimetype}")'
